@@ -2,7 +2,7 @@
 // connect.cpp
 // ~~~~~~~~~~~
 //
-// Copyright (c) 2003-2023 Christopher M. Kohlhoff (chris at kohlhoff dot com)
+// Copyright (c) 2003-2024 Christopher M. Kohlhoff (chris at kohlhoff dot com)
 //
 // Distributed under the Boost Software License, Version 1.0. (See accompanying
 // file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
@@ -802,6 +802,13 @@ void test_async_connect_range()
   io_context.run();
   ASIO_CHECK(result == endpoints[1]);
   ASIO_CHECK(!ec);
+
+  asio::async_connect(socket, endpoints)(
+      bindns::bind(range_handler, _1, _2, &ec, &result));
+  io_context.restart();
+  io_context.run();
+  ASIO_CHECK(result == endpoints[1]);
+  ASIO_CHECK(!ec);
 }
 
 void test_async_connect_range_cond()
@@ -958,6 +965,13 @@ void test_async_connect_range_cond()
   io_context.run();
   ASIO_CHECK(result == asio::ip::tcp::endpoint());
   ASIO_CHECK(ec == asio::error::not_found);
+
+  asio::async_connect(socket, endpoints, false_cond)(
+      bindns::bind(range_handler, _1, _2, &ec, &result));
+  io_context.restart();
+  io_context.run();
+  ASIO_CHECK(result == asio::ip::tcp::endpoint());
+  ASIO_CHECK(ec == asio::error::not_found);
 }
 
 void test_async_connect_iter()
@@ -1003,6 +1017,13 @@ void test_async_connect_iter()
   io_context.run();
   ASIO_CHECK(result == cendpoints.begin() + 1);
   ASIO_CHECK(!ec);
+
+  asio::async_connect(socket, cendpoints.begin(), cendpoints.end())(
+      bindns::bind(iter_handler, _1, _2, &ec, &result));
+  io_context.restart();
+  io_context.run();
+  ASIO_CHECK(result == cendpoints.begin() + 1);
+  ASIO_CHECK(!ec);
 }
 
 void test_async_connect_iter_cond()
@@ -1160,6 +1181,14 @@ void test_async_connect_iter_cond()
   io_context.run();
   ASIO_CHECK(result == cendpoints.end());
   ASIO_CHECK(ec == asio::error::not_found);
+
+  asio::async_connect(socket, cendpoints.begin(),
+      cendpoints.end(), false_cond)(
+        bindns::bind(iter_handler, _1, _2, &ec, &result));
+  io_context.restart();
+  io_context.run();
+  ASIO_CHECK(result == cendpoints.end());
+  ASIO_CHECK(ec == asio::error::not_found);
 }
 
 ASIO_TEST_SUITE
